@@ -35,7 +35,7 @@ class Sponsor(models.Model):
     __metaclass__ = TransMeta
 
     name = models.CharField(max_length=100)
-    description = models.TextField(validators=[MaxLengthValidator(1000)])
+    description = models.TextField()
     url = models.URLField()
     category = models.ForeignKey(Category)
     logo = models.ImageField(upload_to='sponsors')
